@@ -1,6 +1,4 @@
-import os
-
-from copilot import history_file
+from copilot import history_file, shell_adapter
 
 
 def _is_command(line):
@@ -11,43 +9,46 @@ def _formatted(command):
     return command.replace("- cmd: ", "").strip()[:100]
 
 
-def _fish_history(n):
+def _fish_commands():
     lines = history_file.fish_history_file_lines()
-    if len(lines) == 0:
-        return ""
     commands = [_formatted(command) for command in lines if _is_command(command)]
-    commands = list(dict.fromkeys(commands))
-    most_recent_commands = "\n".join(commands[-n:])
-    history = f"""
-The user has recently run these last {min(len(lines), n)} commands:
-{most_recent_commands}
-    """
-    return history
+    return commands
 
 
-def _zsh_history(n):
+def _zsh_commands():
     lines = history_file.zsh_history_file_lines()
-    if len(lines) == 0:
-        return ""
     commands = [command.strip() for command in lines if command != ""]
+    return commands
+
+
+def _bash_commands():
+    lines = history_file.bash_history_file_lines()
+    commands = [command.strip() for command in lines if command != ""]
+    return commands
+
+
+def history_prompt_for(commands, n):
+    if len(commands) == 0:
+        return ""
     commands = list(dict.fromkeys(commands))
     most_recent_commands = "\n".join(commands[-n:])
     history = f"""
-The user has recently run these last {min(len(lines), n)} commands:
+The user has recently run these last {min(len(commands), n)} commands:
 {most_recent_commands}
     """
     return history
 
 
-def get_history(history_context_size=40):
-    if os.environ["SHELL"].endswith("fish"):
-        return _fish_history(history_context_size)
-    if os.environ["SHELL"].endswith("zsh"):
-        return _zsh_history(history_context_size)
+def get_history(n=40):
+    if shell_adapter.is_fish():
+        return history_prompt_for(_fish_commands(), n)
+    if shell_adapter.is_zsh():
+        return history_prompt_for(_zsh_commands(), n)
+    if shell_adapter.is_bash():
+        return history_prompt_for(_bash_commands(), n)
     else:
         return ""
 
 
 def save(cmd):
-    if os.environ["SHELL"].endswith("fish"):
-        history_file.save(cmd)
+    history_file.save(cmd)
